<?php
include $_SERVER['DOCUMENT_ROOT'] . '/wp-load.php';


/**
 * Function for filtering email recipient and returning blank, so that the email won't actually send when we preview.
 *
 * @param $recipient
 * @param $object
 * @param $class
 *
 * @return string
 */
function bt_remove_email_recipient( $recipient, $object, $class ) {
	//error_log( __METHOD__ . ' -- CLASS = ' . class_basename( $class ) );
	return '';
}


// check for authorized user
if ( bt_can_admin_marketplace() || bt_is_seller() ) {

	// get theme-supports options for this
	if ( ! $options = bt_use_sellers( 'preview_emails' ) ) {
		wp_die( 'No theme support for bt-sellers preview_emails' );
	}

	// validate email to preview
	$allowed_emails = $options['allowed_emails'];
	if ( ! array_key_exists( $_REQUEST['email'], $allowed_emails ) ) {
		wp_die( 'Invalid email requested.' );
	}
	$email_class = $allowed_emails[$_REQUEST['email']];

	// validate shipping method to use
	$allowed_shipping = $options['allowed_shipping'];
	if ( ! array_key_exists( $_REQUEST['shipping'], $allowed_shipping ) ) {
		wp_die( 'Invalid shipping requested.' );
	}
	$shipping_method = $allowed_shipping[$_REQUEST['shipping']];

	// update the shipping item if need be
	$shipping_item = new \WC_Order_Item_Shipping( $options['shipping_item_id'] );
	if ( $shipping_item->get_method_id() != $_REQUEST['shipping'] ) {
		$shipping_item->set_method_id( $_REQUEST['shipping'] );
		$shipping_item->set_method_title( $shipping_method['title'] );
		$shipping_item->set_instance_id( $shipping_method['instance_id'] );
		$shipping_item->set_total( $shipping_method['cost'] );
		$shipping_item->save();
		//error_log( __METHOD__ . ' -- MODIFIED shipping item = ' . print_r( $shipping_item->get_data(), true ) );
	}

	// temporarily set the owner/author of the test product to be the current user
	// THIS DICTATES SELLER IN EMAIL!
	wp_update_post( [
		'ID'          => $options['product_id'],
		'post_author' => get_current_user_id(),
	] );

	// get WC emails
	$wc_emails = new \WC_Emails();
	$emails = $wc_emails->get_emails();

	// select the email we want
	$new_email = $emails[$email_class];

	// remove recipient temporarily so it won't send for real
	$email_recipient_filter = 'woocommerce_email_recipient_' . $_REQUEST['email'];
	add_filter( $email_recipient_filter, 'bt_remove_email_recipient', 9988, 3 );

	// trigger the email, which does various setup/processing and normally also sends the email
	$new_email->trigger( $options['order_id'] );

	// remove filter that removes recipient
	remove_filter( $email_recipient_filter, 'bt_remove_email_recipient', 9988 );

	// show the email content
	$content = $new_email->get_content();
	$content = apply_filters( 'woocommerce_mail_content', $new_email->style_inline( $content ) );
	echo $content;

	// reset product ownership to Test Member
	wp_update_post( [
		'ID'          => $options['product_id'],
		'post_author' => $options['seller_id'],
	] );

} else {
	wp_die( 'Not authorized.' );
}
